"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkFilterValidity = void 0;
const isString_1 = require("../general/isString");
const isArrayOfStrings_1 = require("../general/isArrayOfStrings");
const toArray_1 = require("../general/toArray");
const namespaces_1 = require("../../data/namespaces");
const schemaModules_1 = require("../../data/schemaModules");
const isBoolean_1 = require("../general/isBoolean");
function checkFilterValidity(filter) {
    if (!filter) {
        return;
    }
    if (filter.schemaModule !== undefined && filter.schemaModuleExclude !== undefined) {
        throw new Error("The filters schemaModule and schemaModuleExclude must not be used at the same time!");
    }
    if (filter.termType !== undefined && filter.termTypeExclude !== undefined) {
        throw new Error("The filters termType and termTypeExclude must not be used at the same time!");
    }
    if (filter.fromVocabulary !== undefined && filter.fromVocabularyExclude !== undefined) {
        throw new Error("The filters fromVocabulary and fromVocabularyExclude must not be used at the same time!");
    }
    valOrArrayOfValCheck(filter.termType, "termType", namespaces_1.isTermTypeLabelValue);
    valOrArrayOfValCheck(filter.termTypeExclude, "termTypeExclude", namespaces_1.isTermTypeLabelValue);
    valOrArrayOfValCheck(filter.schemaModule, "schemaModule", schemaModules_1.isSchemaModule);
    valOrArrayOfValCheck(filter.schemaModuleExclude, "schemaModuleExclude", schemaModules_1.isSchemaModule);
    valOrArrayOfValCheck(filter.fromVocabulary, "fromVocabulary");
    valOrArrayOfValCheck(filter.fromVocabularyExclude, "fromVocabularyExclude");
    if (filter.isSuperseded !== undefined && !(0, isBoolean_1.isBoolean)(filter.isSuperseded)) {
        throw new Error("The filter isSuperseded must have true or false as value");
    }
}
exports.checkFilterValidity = checkFilterValidity;
function valOrArrayOfValCheck(filterValue, filterLabel, valueFunction) {
    if (filterValue) {
        if (!(0, isString_1.isString)(filterValue) && !(0, isArrayOfStrings_1.isArrayOfStrings)(filterValue)) {
            throw new Error("The filter " + filterLabel + " must have a string or an array of strings as value");
        }
        if (valueFunction) {
            const invalidValue = (0, toArray_1.toArray)(filterValue).find((el) => !valueFunction(el));
            if (invalidValue) {
                throw new Error("Invalid value for filter " + filterLabel + ":" + invalidValue);
            }
        }
    }
}
//# sourceMappingURL=checkFilterValidity.js.map